==> com.liferay.layout.content.page.editor.web-1.0.20.jar: META-INF/resources/js/components/toolbar/TranslationStatus.es.js <==
"use strict";

Liferay.Loader.define("layout-content-page-editor-web@1.0.20/js/components/toolbar/TranslationStatus.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', '../../store/ConnectedComponent.es', '../../actions/actions.es', '../../utils/constants', '../../utils/prefixSegmentsExperienceId.es', '../../utils/FragmentsEditorUpdateUtils.es', './TranslationStatus.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = exports.ConnectedTranslationStatus = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _ConnectedComponent = _interopRequireDefault(require("../../store/ConnectedComponent.es"));

  var _actions = require("../../actions/actions.es");

  var _constants = require("../../utils/constants");

  var _prefixSegmentsExperienceId = require("../../utils/prefixSegmentsExperienceId.es");

  var _FragmentsEditorUpdateUtils = require("../../utils/FragmentsEditorUpdateUtils.es");

  var _TranslationStatus = _interopRequireDefault(require("./TranslationStatus.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
  }

  function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance");
  }

  function _iterableToArray(iter) {
    if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
  }

  function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) {
      for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) {
        arr2[i] = arr[i];
      }return arr2;
    }
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * TranslationStatus
   */
  var TranslationStatus =
  /*#__PURE__*/
  function (_Component) {
    _inherits(TranslationStatus, _Component);

    function TranslationStatus() {
      _classCallCheck(this, TranslationStatus);

      return _possibleConstructorReturn(this, _getPrototypeOf(TranslationStatus).apply(this, arguments));
    }

    _createClass(TranslationStatus, [{
      key: "prepareStateForRender",

      /**
       * @inheritDoc
       * @review
       */
      value: function prepareStateForRender(state) {
        var nextState = state;
        var editableValues = Object.values(state.fragmentEntryLinks).filter(function (fragmentEntryLink) {
          return fragmentEntryLink.editableValues;
        }).map(function (fragmentEntryLink) {
          return [].concat(_toConsumableArray(Object.values(fragmentEntryLink.editableValues[_constants.EDITABLE_FRAGMENT_ENTRY_PROCESSOR] || {})), _toConsumableArray(Object.values(fragmentEntryLink.editableValues[_constants.BACKGROUND_IMAGE_FRAGMENT_ENTRY_PROCESSOR] || {})));
        }).reduce(function (editableValuesA, editableValuesB) {
          return [].concat(_toConsumableArray(editableValuesA), _toConsumableArray(editableValuesB));
        }, []);
        nextState = (0, _FragmentsEditorUpdateUtils.setIn)(nextState, ['translationStatus'], {
          languageValues: Object.keys(state.availableLanguages).map(function (languageId) {
            return {
              languageId: languageId,
              values: editableValues.filter(function (editableValue) {
                return TranslationStatus._editableValueIsTranslated(editableValue, languageId, (0, _prefixSegmentsExperienceId.prefixSegmentsExperienceId)(state.segmentsExperienceId || state.defaultSegmentsExperienceId));
              })
            };
          }),
          translationKeys: editableValues
        });
        nextState.translationStatus.languageValues.sort(function (languageValueA, languageValueB) {
          return languageValueB.values.length - languageValueA.values.length;
        });
        return nextState;
      }
      /**
       * Handles a click on a language item to notify parent components that a
       * change in the selected language needs to be initiated.
       * @param {Event} event
       * @private
       * @review
       */

    }, {
      key: "_handleLanguageChange",
      value: function _handleLanguageChange(event) {
        event.preventDefault();
        this.store.dispatch({
          languageId: event.delegateTarget.getAttribute('data-languageid'),
          type: _actions.CHANGE_LANGUAGE_ID
        });
      }
    }], [{
      key: "_editableValueIsTranslated",

      /**
       * @param {object} editableValue
       * @param {string} languageId
       * @param {string} segmentExperienceId
       * @return {boolean}
       */
      value: function _editableValueIsTranslated(editableValue, languageId, segmentExperienceId) {
        return editableValue[languageId] || segmentExperienceId in editableValue && editableValue[segmentExperienceId][languageId];
      }
    }]);

    return TranslationStatus;
  }(_metalComponent.default);

  var ConnectedTranslationStatus = (0, _ConnectedComponent.default)(TranslationStatus, ['availableLanguages', 'defaultLanguageId', 'defaultSegmentsExperienceId', 'fragmentEntryLinks', 'languageId', 'segmentsExperienceId', 'spritemap']);
  exports.ConnectedTranslationStatus = ConnectedTranslationStatus;

  _metalSoy.default.register(ConnectedTranslationStatus, _TranslationStatus.default);

  var _default = ConnectedTranslationStatus;
  exports.default = _default;
  //# sourceMappingURL=TranslationStatus.es.js.map
});
//# sourceMappingURL=TranslationStatus.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/toolbar/TranslationStatus.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/toolbar/TranslationStatus.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', '../../actions/actions.es', '../../store/ConnectedComponent.es', '../../utils/FragmentsEditorUpdateUtils.es', '../../utils/constants', '../../utils/prefixSegmentsExperienceId.es', './TranslationStatus.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.ConnectedTranslationStatus = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _actions = require("../../actions/actions.es");

  var _ConnectedComponent = _interopRequireDefault(require("../../store/ConnectedComponent.es"));

  var _FragmentsEditorUpdateUtils = require("../../utils/FragmentsEditorUpdateUtils.es");

  var _constants = require("../../utils/constants");

  var _prefixSegmentsExperienceId = require("../../utils/prefixSegmentsExperienceId.es");

  var _TranslationStatus = _interopRequireDefault(require("./TranslationStatus.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
  }

  function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance");
  }

  function _iterableToArray(iter) {
    if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
  }

  function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) {
      for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) {
        arr2[i] = arr[i];
      }return arr2;
    }
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * TranslationStatus
   */
  var TranslationStatus =
  /*#__PURE__*/
  function (_Component) {
    _inherits(TranslationStatus, _Component);

    function TranslationStatus() {
      _classCallCheck(this, TranslationStatus);

      return _possibleConstructorReturn(this, _getPrototypeOf(TranslationStatus).apply(this, arguments));
    }

    _createClass(TranslationStatus, [{
      key: "prepareStateForRender",

      /**
       * @inheritDoc
       * @review
       */
      value: function prepareStateForRender(state) {
        var nextState = state;
        var editableValues = Object.values(state.fragmentEntryLinks).filter(function (fragmentEntryLink) {
          return fragmentEntryLink.editableValues;
        }).map(function (fragmentEntryLink) {
          return [].concat(_toConsumableArray(Object.values(fragmentEntryLink.editableValues[_constants.EDITABLE_FRAGMENT_ENTRY_PROCESSOR] || {})), _toConsumableArray(Object.values(fragmentEntryLink.editableValues[_constants.BACKGROUND_IMAGE_FRAGMENT_ENTRY_PROCESSOR] || {})));
        }).reduce(function (editableValuesA, editableValuesB) {
          return [].concat(_toConsumableArray(editableValuesA), _toConsumableArray(editableValuesB));
        }, []);
        nextState = (0, _FragmentsEditorUpdateUtils.setIn)(nextState, ['translationStatus'], {
          languageValues: Object.keys(state.availableLanguages).map(function (languageId) {
            return {
              languageId: languageId,
              values: editableValues.filter(function (editableValue) {
                return TranslationStatus._editableValueIsTranslated(editableValue, languageId, (0, _prefixSegmentsExperienceId.prefixSegmentsExperienceId)(state.segmentsExperienceId || state.defaultSegmentsExperienceId));
              })
            };
          }),
          translationKeys: editableValues
        });
        nextState.translationStatus.languageValues.sort(function (languageValueA, languageValueB) {
          return languageValueB.values.length - languageValueA.values.length;
        });
        return nextState;
      }
      /**
       * Handles a click on a language item to notify parent components that a
       * change in the selected language needs to be initiated.
       * @param {Event} event
       * @private
       * @review
       */

    }, {
      key: "_handleLanguageChange",
      value: function _handleLanguageChange(event) {
        event.preventDefault();
        this.store.dispatch({
          type: _actions.CHANGE_LANGUAGE_ID,
          value: event.delegateTarget.getAttribute('data-languageid')
        });
      }
    }], [{
      key: "_editableValueIsTranslated",

      /**
       * @param {object} editableValue
       * @param {string} languageId
       * @param {string} segmentExperienceId
       * @return {boolean}
       */
      value: function _editableValueIsTranslated(editableValue, languageId, segmentExperienceId) {
        return editableValue[languageId] || segmentExperienceId in editableValue && editableValue[segmentExperienceId][languageId];
      }
    }]);

    return TranslationStatus;
  }(_metalComponent["default"]);

  var ConnectedTranslationStatus = (0, _ConnectedComponent["default"])(TranslationStatus, ['availableLanguages', 'defaultLanguageId', 'defaultSegmentsExperienceId', 'fragmentEntryLinks', 'languageId', 'segmentsExperienceId', 'spritemap']);
  exports.ConnectedTranslationStatus = ConnectedTranslationStatus;

  _metalSoy["default"].register(ConnectedTranslationStatus, _TranslationStatus["default"]);

  var _default = ConnectedTranslationStatus;
  exports["default"] = _default;
  //# sourceMappingURL=TranslationStatus.es.js.map
});
//# sourceMappingURL=TranslationStatus.es.js.map
